Instantiator

Struct Instantiator 

pub struct Instantiator { /* private fields */ }
Instantiates global data on creation and deinstantiates it on drop

This struct instantiates global data upon creation and deinstantiates it upon drop. It also is responsible for calling the writers when the data is collected.

Using instantiate! macro instead of this struct is recommened.

Implementations

Source

impl Instantiator

pub fn new(writers: Vec<Box<dyn Writer + 'static>>) -> Instantiator

Constructs the instantiator

The writers will be called in end method.

pub fn end(&mut self)

Deinstantiates global variables and calls the writers

This method is used when Instantiator is never dropped.