pub struct Instantiator { /* private fields */ }Expand description
Instantiates global data on creation and deinstantiates it on drop
This struct instantiates global data upon creation and deinstantiates it upon drop. It also is responsible for calling the writers when the data is collected.
Using instantiate! macro instead of this struct is recommened.
Implementations
Sourceimpl Instantiator
impl Instantiator